import type { PaginationConfiguration } from "@smithy/types";
import { SSOClient } from "../SSOClient";
/**
 * @public
 */
export interface SSOPaginationConfiguration extends PaginationConfiguration {
    client: SSOClient;
}
