import { PaginationConfiguration } from "@smithy/types";
import { SSOClient } from "../SSOClient";
export interface SSOPaginationConfiguration extends PaginationConfiguration {
  client: SSOClient;
}
